# :coffee: JAVA

- Java 基础
- GOF 23 种设计模式
- 深入理解 Java 虚拟机
- 网络编程原理
- Netty 编程模式



## 💻 前端基础

- JavaScript 基础
- 原型与原型链，作用域与闭包，异步与单线程
- ECMAScript 6.0 基础
- WebPack 基础
- Vue 核心概念



## 💾 数据库

### MySQL

+ [MySQL 核心概念](notes/MySQL_基础.md)
+ [MySQL 备份详解](notes/MySQL_备份.md)
+ [MySQL 二进制日志复制、GTID 复制与半同步复制](notes/MySQL_复制.md)
+ [MySQL 高可用架构之 PXC 集群](notes/MySQL_PXC集群.md)
+ [MyCat 读写分离与分库分表](notes/MySQL_Mycat中间件.md)
+ [MySQL 查询性能分析之 Explain](notes/MySQL_EXPLAIN.md)

### Redis

+ [Redis 基本数据类型和常用命令](notes/Redis_数据类型和常用命令.md)
+ [Redis AOF 和 RDB 持久化策略原理](notes/Redis_持久化.md)
+ [Redis 哨兵模式](notes/Redis_哨兵模式.md)
+ [Reids 集群模式](notes/Redis_集群模式.md)

### MongoDB

+ [MongoDB 基础](notes/MongoDB_基础.md)
+ [MongoDB 索引](notes/MongoDB_索引.md)
+ [MongoDB 聚合](notes/MongoDB_聚合.md)
+ [MongoDB 复制](notes/MongoDB_复制.md)
+ [MongoDB 分片](notes/MongoDB_分片.md)



## 📟 操作系统

+ [Linux 常用 Shell 命令](notes/Linux_常用Shell命令.md)
+ [Docker 基础](notes/Docker_基础.md)



## 🌳 Spring 系列

### Spring

+ Spring事务机制、事务的传播与监控

### Spring Cloud

- Eureka 服务的注册和发现
- Eureka 高可用集群搭建
- Ribbon 客户端负载均衡，RestTemplate 服务远程调用
- OpenFeign 声明式服务调用，服务容错处理
- Hystix 服务容错保护，Hystrix Dashboard 断路器监控，Turbine 断路器聚合监控
- Zuul 网关服务
- Sleuth + Zipkin 服务链路追踪
- Config 分布式配置中心 ，集成 Bus 消息总线实现配置热更新

### 分布式解决方案

+ 全局 ID 生成方案
+ 分布式 Session 解决方案
+ 分布式锁解决方案
+ 分布式事务解决方案实战



## 常用技术栈

### Kafka

1. [Kafka 简介](https://github.com/heibaiying/BigData-Notes/blob/master/notes/Kafka简介.md)
2. [基于 Zookeeper 搭建 Kafka 高可用集群](https://github.com/heibaiying/BigData-Notes/blob/master/notes/installation/基于Zookeeper搭建Kafka高可用集群.md)
3. [Kafka 生产者详解](https://github.com/heibaiying/BigData-Notes/blob/master/notes/Kafka生产者详解.md)
4. [Kafka 消费者详解](https://github.com/heibaiying/BigData-Notes/blob/master/notes/Kafka消费者详解.md)
5. [深入理解 Kafka 副本机制](https://github.com/heibaiying/BigData-Notes/blob/master/notes/Kafka深入理解分区副本机制.md)

### RabbitMQ

- [RabbitMQ 核心概念](notes/RabbitMQ_基础.md)
- [RabbitMQ 客户端开发](notes/RabbitMQ_客户端开发.md)
- [基于 HAProxy + KeepAlived 搭建 RabbitMQ 高可用集群](notes/RabbitMQ_高可用集群架构.md)

### ZooKeeper 

1. [ZooKeeper 简介及核心概念](https://github.com/heibaiying/BigData-Notes/blob/master/notes/Zookeeper简介及核心概念.md)
2. [ZooKeeper 单机环境和集群环境搭建](https://github.com/heibaiying/BigData-Notes/blob/master/notes/installation/Zookeeper单机环境和集群环境搭建.md) 
3. [ZooKeeper 常用 Shell 命令](https://github.com/heibaiying/BigData-Notes/blob/master/notes/Zookeeper常用Shell命令.md)
4. [ZooKeeper Java 客户端 —— Apache Curator](https://github.com/heibaiying/BigData-Notes/blob/master/notes/Zookeeper_Java客户端Curator.md)
5. [ZooKeeper  ACL 权限控制](https://github.com/heibaiying/BigData-Notes/blob/master/notes/Zookeeper_ACL权限控制.md)

### Nginx

- [Nginx 基础之静态网站部署，负载均衡，动静分离](notes/Nginx_基础.md)



## 📊 算法

TODO
